[−][src]Crate amadeus_types
Implementations of Rust types that correspond to Parquet logical types.
Record is implemented for each of them.
Structs
| Bson | A Rust type corresponding to the Bson logical type. |
| Date | |
| DowncastError | |
| Enum | A Rust type corresponding to the Enum logical type. |
| Group | A Rust type corresponding to Parquet groups of fields. |
| Json | A Rust type corresponding to the Json logical type. |
| List |
|
| Map |
|
| Time | |
| Timestamp | |
| Webpage |
Enums
| Decimal | Rust representation for Decimal values. |
| Schema | |
| SchemaIncomplete | |
| Value | Represents any valid Parquet value. |
| ValueRequired | Represents any valid required Parquet value. Exists to avoid |
Traits
| Downcast | |
| DowncastImpl | This trait lets one downcast a generic type like |