[−][src]Enum amadeus_types::Decimal
Rust representation for Decimal values.
This is not a representation of Parquet physical type, but rather a wrapper for DECIMAL logical type, and serves as container for raw parts of decimal values: unscaled value in bytes, precision and scale.
Variants
Int32Decimal backed by i32.
Fields of Int32
Int64Decimal backed by i64.
Fields of Int64
BytesDecimal backed by byte array.
Fields of Bytes
Methods
impl Decimal[src]
pub fn from_bytes(value: Vec<u8>, precision: i32, scale: i32) -> Self[src]
Creates new decimal value from Vec<u8>.
pub fn data(&self) -> &[u8][src]
Returns bytes of unscaled value.
pub fn precision(&self) -> i32[src]
Returns decimal precision.
pub fn scale(&self) -> i32[src]
Returns decimal scale.