Timezone

Struct Timezone 

pub struct Timezone { /* private fields */ }
A timezone. It can have a varying offset, like Europe/London, or fixed like GMT+1.

Implementations

Source

impl Timezone

pub const UTC: Self

pub const GMT: Self

pub const GMT_MINUS_1: Self

pub const GMT_MINUS_2: Self

pub const GMT_MINUS_3: Self

pub const GMT_MINUS_4: Self

pub const GMT_MINUS_5: Self

pub const GMT_MINUS_6: Self

pub const GMT_MINUS_7: Self

pub const GMT_MINUS_8: Self

pub const GMT_MINUS_9: Self

pub const GMT_MINUS_10: Self

pub const GMT_MINUS_11: Self

pub const GMT_MINUS_12: Self

pub const GMT_PLUS_1: Self

pub const GMT_PLUS_2: Self

pub const GMT_PLUS_3: Self

pub const GMT_PLUS_4: Self

pub const GMT_PLUS_5: Self

pub const GMT_PLUS_6: Self

pub const GMT_PLUS_7: Self

pub const GMT_PLUS_8: Self

pub const GMT_PLUS_9: Self

pub const GMT_PLUS_10: Self

pub const GMT_PLUS_11: Self

pub const GMT_PLUS_12: Self

pub const GMT_PLUS_13: Self

pub const GMT_PLUS_14: Self

pub fn from_name(name: &str) -> Option<Self>

Create a new Timezone from a name in the IANA Database.

pub fn as_name(&self) -> Option<&'static str>

Get the name of the timezone as in the IANA Database. It might differ from (although still be equivalent to) the name given to from_name.

pub fn from_offset(seconds: i32) -> Option<Self>

Makes a new Timezone for the Eastern Hemisphere with given timezone difference. The negative seconds means the Western Hemisphere.

pub fn as_offset(&self) -> Option<i32>

Returns the number of seconds to add to convert from UTC to the local time.

pub fn as_offset_at(&self, utc_date_time: &DateTime) -> i32

Returns the number of seconds to add to convert from UTC to the local time.